==> flatnuke_2.7.orig.tar.gz: flatnuke-2.7/languages/admin/en.php <==
<?php
/*
 * @author Marco Segato <segatom@users.sourceforge.net>
 */

//2.7
define ("_FNCC_FNOPTIONS",	"Flatnuke options");
define ("_FNCC_SERVERINFOS",	"Server<br />informations");
define ("_FNCC_GENERALCONF",	"General<br />configuration");
define ("_FNCC_FILEMANAGER",	"File<br />manager");
define ("_FNCC_MANAGEFN",	"Website management");
define ("_FNCC_NEWS",	"Manage<br />news");
define ("_FNCC_NEWSBYUSERS",	"News by<br />users");
define ("_FNCC_MOTD",	"Edit<br>welcome");
define ("_FNCC_POLL",	"Manage<br>poll");
define ("_FNCC_USERS",	"Manage users");
define ("_FNCC_USERSLIST",	"Members'<br />list");
define ("_FNCC_ADDUSER",	"New<br />user");
define ("_FNCC_SECURITY",	"Manage security");
define ("_FNCC_BACKUPS",	"Website<br />backup");
define ("_FNCC_LOGS",	"Manage<br />logs");
define ("_FNCC_BLACKLISTS",	"Manage<br />blacklists");
define ("_FNCC_THEME",	"Theme options");
define ("_FNCC_THEMESTRUCTURE",	"Theme<br>structure");
define ("_FNCC_THEMESTYLE",	"Theme<br>style");
define ("_FNCC_CSSTHEME",	"CSS<br>theme");
define ("_FNCC_CSSFORUM",	"CSS<br>forum");
define ("_FNCC_NOGDLIB",	"This extension is not installed (<a href='http://www.libgd.org/FAQ_PHP' target='_blank'>?</a>)");
define ("_FNCC_SERVERINFO",	"Informations about server");
define ("_FNCC_SITEURL",	"Host URL: ");
define ("_FNCC_OS",	"Operative system: ");
define ("_FNCC_WEBSERVER",	"Web server: ");
define ("_FNCC_PHP",	"PHP version: ");
define ("_FNCC_GDLIB",	"GD library version: ");
define ("_FNCC_FLATNUKE",	"Flatnuke version: ");
define ("_FNCC_FNUNKNOWN",	"unknown");
define ("_FNCC_SERVERSPACE",	"Available space on the server: ");
define ("_FNCC_SITESPACE",	"Current site dimensions: ");
define ("_FNCC_MYINFOS",	"About me");
define ("_FNCC_IP",	"IP address: ");
define ("_FNCC_USERAGENT",	"Browser: ");
define ("_FNCC_DESGENERALCONF",	"Flatnuke general configuration");
define ("_FNCC_DESMOTD",	"Edit welcome message");
define ("_FNCC_DESNEWS",	"Manage the news of your site");
define ("_FNCC_DESNEWSBYUSERS",	"Manage news proposed by other users");
define ("_FNCC_DESPOLL",	"Manage current poll");
define ("_FNCC_DESUSERSLIST",	"List of site members");
define ("_FNCC_DESADDUSER",	"Add a new member to the site");
define ("_FNCC_DESBACKUPS",	"Manage site's backup");
define ("_FNCC_DESLOGS",	"Manage Flatnuke logs");
define ("_FNCC_DESBLACKLISTS",	"Manage Flatnuke blacklists");
define ("_FNCC_DESTHEMESTRUCTURE",	"Edit current theme's structure");
define ("_FNCC_DESTHEMESTYLE",	"Edit current theme's style");
define ("_FNCC_DESCSSTHEME",	"Edit current theme's CSS stylesheet");
define ("_FNCC_DESCSSFORUM",	"Edit forum's CSS stylesheet");
define ("_FNCC_ONLYADMIN",	"Access denied");
define ("_FNCC_DESONLYADMIN",	"You can't access to this page, this section is reserved to the administrator.");
define ("_FNCC_CONFSITENAME",	"Web site title (max. 100 chars):");
define ("_FNCC_CONFSITEDESCRIPTION",	"Web site description (max. 500 chars):");
define ("_FNCC_CONFKEYWORDS",	"List of keywords that describe site contents (max. 1500 chars):");
define ("_FNCC_CONFTHEME",	"Theme:");
define ("_FNCC_CONFNEWSPP",	"Number of news listed in each page (max. 999):");
define ("_FNCC_CONFADMIN",	"Administrator name (max. 100 chars):");
define ("_FNCC_CONFADMINMAIL",	"E-mail address of the administrator (max. 100 chars):");
define ("_FNCC_CONFLANG",	"Language in use:");
define ("_FNCC_CONFREGUSER",	"Let users to register their profile on this site:");
define ("_FNCC_CONFGUESTNEWS",	"Let visitors to propose news:");
define ("_FNCC_CONFGUESTCOMMENT",	"Let visitors to add comments to the news:");
define ("_FNCC_CONFREMEMBERLOGIN",	"Let users to save cookies when making login:");
define ("_FNCC_CONFMAINTENANCE",	"Put the site in maintenance mode (only the admin can make the login):");
define ("_FNCC_CONFHOMESECTION",	"Section to print in site's homepage (put blank if you want to list news):");
define ("_FNCC_CONFTOPICPERPAGE",	"Number of forum's topics in each page (max = 999):");
define ("_FNCC_CONFPOSTPERPAGE",	"Number of forum's messages in each page (max = 999):");
define ("_FNCC_CONFMEMBERPERPAGE",	"Number of members in each page (max = 999):");
define ("_FNCC_CONFFORUMMODERATORS",	"List of forum's moderators (eg: user1,user2,user3), (max 500 chars):");
define ("_FNCC_WARNINGDOC",	"ATTENTION: read Flatnuke documentation before editing this file!");
define ("_FNCC_WARNINGRIGHTS",	"Editing impossible: check write permissions of the file!");
define ("_FNCC_WARNINGNOFILE",	"The file doesn't exists, check Flatnuke installation!");
define ("_FNCC_CHANGEDATE",	"Last edit");
define ("_FNCC_BACKUPNEWS",	"Make backup of the news");
define ("_FNCC_BACKUPUSERS",	"Make backup of the users");
define ("_FNCC_BACKUPMISC",	"Make backup of the directory");
define ("_FNCC_BACKUPSECT",	"Make backup of the sections");
define ("_FNCC_BACKUPFORUM",	"Make backup of the forum");
define ("_FNCC_BACKUPSITE",	"Make backup of all the site");
define ("_FNCC_DELBACKUP",	"Delete temporary backup files");
define ("_FNCC_SAVE",	"Save");
define ("_FNCC_LOGLIST",	"System logs' list");
define ("_FNCC_CLEANLOG",	"Clean log");
define ("_FNCC_MANAGEBLACKLISTS",	"System blacklists");
define ("_FNCC_YES",	"Yes");
define ("_FNCC_NO",	"No");
define ("_FNCC_USERSTOACTIVATE",	"Profiles<br />to activate");
define ("_FNCC_WAITINGUSERS",	"Profiles wating for activation");
define ("_FNCC_NOUSERSTOACTIVATE", "No profiles waiting for activation!");
define ("_FNCC_REGMAIL", "Reg. e-mail");
define ("_FNCC_REGMAILDES", "Edit e-mail address");
define ("_FNCC_REGCODE", "Reg. code");
define ("_FNCC_REGCODEDES", "Send again activation code");
define ("_FNCC_ACTIVATE", "Activate");

?>

==> flatnuke_2.7.2.orig.tar.gz: flatnuke-2.7.2/languages/admin/en.php <==
<?php
/*
 * @author Marco Segato <segatom@users.sourceforge.net>
 */

//2.7
define ("_FNCC_FNOPTIONS",	"Flatnuke options");
define ("_FNCC_SERVERINFOS",	"Server<br />informations");
define ("_FNCC_GENERALCONF",	"General<br />configuration");
define ("_FNCC_FILEMANAGER",	"File<br />manager");
define ("_FNCC_MANAGEFN",	"Website management");
define ("_FNCC_NEWS",	"Manage<br />news");
define ("_FNCC_NEWSBYUSERS",	"News by<br />users");
define ("_FNCC_MOTD",	"Edit<br>welcome");
define ("_FNCC_POLL",	"Manage<br>poll");
define ("_FNCC_USERS",	"Manage users");
define ("_FNCC_USERSLIST",	"Members'<br />list");
define ("_FNCC_ADDUSER",	"New<br />user");
define ("_FNCC_SECURITY",	"Manage security");
define ("_FNCC_BACKUPS",	"Website<br />backup");
define ("_FNCC_LOGS",	"Manage<br />logs");
define ("_FNCC_BLACKLISTS",	"Manage<br />blacklists");
define ("_FNCC_THEME",	"Theme options");
define ("_FNCC_THEMESTRUCTURE",	"Theme<br>structure");
define ("_FNCC_THEMESTYLE",	"Theme<br>style");
define ("_FNCC_CSSTHEME",	"CSS<br>theme");
define ("_FNCC_CSSFORUM",	"CSS<br>forum");
define ("_FNCC_NOGDLIB",	"This extension is not installed (<a href='http://www.libgd.org/FAQ_PHP' target='_blank'>?</a>)");
define ("_FNCC_SERVERINFO",	"Informations about server");
define ("_FNCC_SITEURL",	"Host URL: ");
define ("_FNCC_OS",	"Operative system: ");
define ("_FNCC_WEBSERVER",	"Web server: ");
define ("_FNCC_PHP",	"PHP version: ");
define ("_FNCC_GDLIB",	"GD library version: ");
define ("_FNCC_FLATNUKE",	"Flatnuke version: ");
define ("_FNCC_FNUNKNOWN",	"unknown");
define ("_FNCC_SERVERSPACE",	"Available space on the server: ");
define ("_FNCC_SITESPACE",	"Current site dimensions: ");
define ("_FNCC_MYINFOS",	"About me");
define ("_FNCC_IP",	"IP address: ");
define ("_FNCC_USERAGENT",	"Browser: ");
define ("_FNCC_DESGENERALCONF",	"Flatnuke general configuration");
define ("_FNCC_DESMOTD",	"Edit welcome message");
define ("_FNCC_DESNEWS",	"Manage the news of your site");
define ("_FNCC_DESNEWSBYUSERS",	"Manage news proposed by other users");
define ("_FNCC_DESPOLL",	"Manage current poll");
define ("_FNCC_DESUSERSLIST",	"List of site members");
define ("_FNCC_DESADDUSER",	"Add a new member to the site");
define ("_FNCC_DESBACKUPS",	"Manage site's backup");
define ("_FNCC_DESLOGS",	"Manage Flatnuke logs");
define ("_FNCC_DESBLACKLISTS",	"Manage Flatnuke blacklists");
define ("_FNCC_DESTHEMESTRUCTURE",	"Edit current theme's structure");
define ("_FNCC_DESTHEMESTYLE",	"Edit current theme's style");
define ("_FNCC_DESCSSTHEME",	"Edit current theme's CSS stylesheet");
define ("_FNCC_DESCSSFORUM",	"Edit forum's CSS stylesheet");
define ("_FNCC_ONLYADMIN",	"Access denied");
define ("_FNCC_DESONLYADMIN",	"You can't access to this page, this section is reserved to the administrator.");
define ("_FNCC_CONFSITENAME",	"Web site title (max. 100 chars):");
define ("_FNCC_CONFSITEDESCRIPTION",	"Web site description (max. 500 chars):");
define ("_FNCC_CONFKEYWORDS",	"List of keywords that describe site contents (max. 1500 chars):");
define ("_FNCC_CONFTHEME",	"Theme:");
define ("_FNCC_CONFNEWSPP",	"Number of news listed in each page (max. 999):");
define ("_FNCC_CONFADMIN",	"Administrator name (max. 100 chars):");
define ("_FNCC_CONFADMINMAIL",	"E-mail address of the administrator (max. 100 chars):");
define ("_FNCC_CONFLANG",	"Language in use:");
define ("_FNCC_CONFREGUSER",	"Let users to register their profile on this site:");
define ("_FNCC_CONFGUESTNEWS",	"Let visitors to propose news:");
define ("_FNCC_CONFGUESTCOMMENT",	"Let visitors to add comments to the news:");
define ("_FNCC_CONFREMEMBERLOGIN",	"Let users to save cookies when making login:");
define ("_FNCC_CONFMAINTENANCE",	"Put the site in maintenance mode (only the admin can make the login):");
define ("_FNCC_CONFHOMESECTION",	"Section to print in site's homepage (put blank if you want to list news):");
define ("_FNCC_CONFTOPICPERPAGE",	"Number of forum's topics in each page (max = 999):");
define ("_FNCC_CONFPOSTPERPAGE",	"Number of forum's messages in each page (max = 999):");
define ("_FNCC_CONFMEMBERPERPAGE",	"Number of members in each page (max = 999):");
define ("_FNCC_CONFFORUMMODERATORS",	"List of forum's moderators (eg: user1,user2,user3), (max 500 chars):");
define ("_FNCC_WARNINGDOC",	"ATTENTION: read Flatnuke documentation before editing this file!");
define ("_FNCC_WARNINGRIGHTS",	"Editing impossible: check write permissions of the file!");
define ("_FNCC_WARNINGNOFILE",	"The file doesn't exists, check Flatnuke installation!");
define ("_FNCC_CHANGEDATE",	"Last edit");
define ("_FNCC_BACKUPNEWS",	"Make backup of the news");
define ("_FNCC_BACKUPUSERS",	"Make backup of the users");
define ("_FNCC_BACKUPMISC",	"Make backup of the directory");
define ("_FNCC_BACKUPSECT",	"Make backup of the sections");
define ("_FNCC_BACKUPFORUM",	"Make backup of the forum");
define ("_FNCC_BACKUPSITE",	"Make backup of all the site");
define ("_FNCC_DELBACKUP",	"Delete temporary backup files");
define ("_FNCC_SAVE",	"Save");
define ("_FNCC_LOGLIST",	"System logs' list");
define ("_FNCC_CLEANLOG",	"Clean log");
define ("_FNCC_MANAGEBLACKLISTS",	"System blacklists");
define ("_FNCC_YES",	"Yes");
define ("_FNCC_NO",	"No");
define ("_FNCC_USERSTOACTIVATE",	"Profiles<br />to activate");
define ("_FNCC_WAITINGUSERS",	"Profiles wating for activation");
define ("_FNCC_NOUSERSTOACTIVATE", "No profiles waiting for activation!");
define ("_FNCC_REGMAIL", "Reg. e-mail");
define ("_FNCC_REGMAILDES", "Edit e-mail address");
define ("_FNCC_REGCODE", "Reg. code");
define ("_FNCC_REGCODEDES", "Send again activation code");
define ("_FNCC_ACTIVATE", "Activate");
define ("_FNCC_NEWSEDITOR", "Choose editor for news:");

//2.7.1
define ("_FNCC_DOWNCONF",	"Manage<br />download");
define ("_FNCC_DESDOWNCONF",	"Manage download section ");
define ("_FNCC_FDPEXTENSIONS",	"List of allowed extensions (comma-separated values):");
define ("_FNCC_FDPMAXFILESIZE",	"Maximum file size in bytes (1Mb = 1.000.000 bytes):");
define ("_FNCC_FDPICONSTYLE",	"Icons' theme to use:");
define ("_FNCC_FDPNEWFILETIME",	"Number of hours a file is considered recent (192h = 1 week):");
define ("_FNCC_FDPAUTOMD5",	"Generate MD5 hash of uploaded files:");
define ("_FNCC_FDPAUTOSHA1",	"Generate SHA-1 hash of uploaded files:");
define ("_FNCC_FDPSHOWUPLOADER", "Show the name of the user loaded the file:");
define ("_FNCC_FDPGPG",	"GPG file extension:");
define ("_FNCC_FDPSCREENSHOTS",	"Screenshot preview file extension:");
define ("_FNCC_FDPADMINS",	"List of users that can administrate download sections (comma-separated values):");
define ("_FNCC_FDPADMINOPTOK",	"Enable web administration options:");
define ("_FNCC_FDPSHOWLINK",	"Show \"Download\" link for each file:");
define ("_FNCC_FDPFILELIST",	"Show file list in summary page:");
define ("_FNCC_FDPSUMMARY",	"Show an header at the top of all download sections:");
define ("_FNCC_FDPVOTE",	"Enable voting:");
define ("_FNCC_FDPMAXUSERSIZE",	"Maximum file size in bytes for users' uploads (1Mb = 1.000.000 byte):");
define ("_FNCC_FDPNUMWAITING",	"Maximum number of files waiting to be published:");
define ("_FNCC_FDPFILEWAITING",	"Name of the list with files waiting to be published (READONLY):");
define ("_FNCC_FDPBLACKLIST",	"List of users that can not upload files (comma-separated values):");
define ("_FNCC_FDPMINLEVEL",	"Minimum level of users that can upload files:");

?>
